<?php

/**
 * Main Class for handling the Plugin operation
 *
 * @author jason.xie@victheme.com
 *
 */
class VTCore_CenterLine_Init
{

    private $autoloader;

    private $filters = array(
        'vc_load_default_templates',
    );

    private $actions = array(
        'vc_backend_editor_enqueue_js_css',
        'vc_frontend_editor_enqueue_js_css',
        'vc_load_iframe_jscss',
    );

    private $shortcodes = array(
        'centerline' => 'VTCore_CenterLine_Shortcodes_CenterLine',
        'centerlineimage' => 'VTCore_CenterLine_Shortcodes_CenterLineImage',
        'centerlineinner' => 'VTCore_CenterLine_Shortcodes_CenterLineInner',
        'centerlinesimple' => 'VTCore_CenterLine_Shortcodes_CenterLineSimple',
    );

    private $vcshortcodes = array(
        'VTCore_CenterLine_Visualcomposer_CenterLine',
        'VTCore_CenterLine_Visualcomposer_CenterLineInner',
        'VTCore_CenterLine_Visualcomposer_CenterLineImage',
        'VTCore_CenterLine_Visualcomposer_CenterLineSimple',
    );

    /**
     * Constructing the main class and adding action to init.
     */
    public function __construct()
    {

        // Load autoloader
        $this->autoloader = new VTCore_Autoloader('VTCore_CenterLine', dirname(__FILE__));
        $this->autoloader->setRemovePath('vtcore' . DIRECTORY_SEPARATOR . 'centerline' . DIRECTORY_SEPARATOR);
        $this->autoloader->register();

        // Registering assets
        VTCore_Wordpress_Init::getFactory('assets')
            ->get('library')
            ->detect(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'assets', plugins_url('', __FILE__) . '/assets', false, 'VTCore_CenterLine_Assets');

        // Registering actions
        VTCore_Wordpress_Init::getFactory('filters')
            ->addPrefix('VTCore_CenterLine_Filters_')
            ->addHooks($this->filters)
            ->register();


        // Registering filters
        VTCore_Wordpress_Init::getFactory('actions')
            ->addPrefix('VTCore_CenterLine_Actions_')
            ->addHooks($this->actions)
            ->register();

        // Registering shortcodes
        VTCore_Wordpress_Init::getFactory('shortcodes')
            ->merge($this->shortcodes)
            ->initialize();

        // Register to visual composer via VTCore Visual Composer Factory
        if (VTCore_Wordpress_Init::getFactory('visualcomposer')) {
            VTCore_Wordpress_Init::getFactory('visualcomposer')
                ->mapShortcode($this->vcshortcodes);
        }

        // Force convert shortcode into dotted notation, some theme like flatsome
        // invoke function that messed up with underscore (flatsome_contentfix)
        // This will break in other theme. Only enable on flatsome!
        add_filter('the_content', function ($content) {
            $shortcodes = ['centerline', 'centerlinesimple'];
            foreach ($shortcodes as $shortcode) {
                if (has_shortcode($content, $shortcode)) {
                    $pattern = get_shortcode_regex(array($shortcode));
                    $atts = [];
                    preg_match_all('/' . $pattern . '/s', $content, $atts);
                    if (isset($atts[0][0]) && !empty($atts[0][0])) {
                        $content = str_replace($atts[0][0], str_replace('___', '.', $atts[0][0]), $content);
                    }
                }

            }
            return $content;
        }, 999);
    }

}