/**
 * Javascript for processing the WpPrintPdf Button
 * to print the current page as a pdf
 *
 * To use this, you must mark the page / sections that will be
 * printed using data-printpdf="target", if no target found
 * it will go to body as the target
 *
 *  @author jason.xie@victheme.com
 */
(function ($) {

    if (!window.VT) {
        window.VT = {};
    }

    window.VT.printPDF = {
        init: function(filename, content) {
            this.content = $(content);
            this.filename = filename;
            this.rawImages = this.content.find('img');
            this.images = [];
            this.process();
        },
        process: function() {
            var that = this;

            // Processing images
            this.rawImages.each(function() {
                if ($(this).hasClass('property-need-processing')) {
                    var img = new Image();
                    img.onload = function() {

                        var canvas = document.createElement('canvas'),
                            ctx = canvas.getContext('2d');

                        canvas.height = this.naturalHeight;
                        canvas.width = this.naturalWidth;

                        ctx.drawImage(this, 0, 0);

                        that.images.push(canvas.toDataURL('png'));
                        if (that.images.length === that.rawImages.length) {
                            that.generate();
                        }
                    };

                    img.src = $(this).attr('src');
                }
                else {
                    that.images.push($(this).attr('src'));
                }
            });

            if (that.images.length === that.rawImages.length) {
                that.generate();
            }
        },
        generate: function () {
            var doc = new jsPDF('p', 'pt'),
                that = this,
                $content = this.content,
                res = doc.autoTableHtmlToJson($content.find('table')[0]),
                header = $content.find('#header'),
                yPos = 20;

            // Inject table at the end, this is sucks, we need to find a way
            // to inject as fromHTML is parsing and use the autoTables to style it.
            $content.find('table, img, #header').remove();

            // See if we need to autoload
            doc.setFont('helvetica');

            if (header.length) {
                doc.fromHTML(header.html(), 20, yPos, {
                        'width': 540
                    },
                    function (dispose) {
                        yPos = yPos + dispose.y;

                        // Draw Lines
                        doc.setDrawColor(41, 128, 186);
                        doc.setLineWidth(1);
                        doc.line(20, yPos - 20, 570, yPos - 20);
                    });
            }

            $.each(this.images, function(delta, img) {
                try {
                    doc.addImage(img, 20, yPos, 550, 220);
                    yPos = yPos + 240;
                }
                catch (e) {

                }
            });

            doc.fromHTML($content.html(), 20, yPos, {
                    'width': 540
                },

                // End parsing
                function (dispose) {
                    doc.autoTable(res.columns, res.data, {
                        margin: {
                            left: 20,
                            right: 20,
                            bottom: 20,
                            top: 20
                        },
                        startY: 20 + dispose.y
                    });
                    doc.save(that.filename + '.pdf');
                });

        }
    };

    $(document)
        .on('ajaxComplete.wp-pdf', function (event, xhr, settings) {
            // Support for wp-pdf only.
            if (settings.marker && settings.marker == 'wp-pdf') {
                var AjaxData = $.fn.VTCoreProcessAjaxResponse(xhr.responseText);
                AjaxData.content
                    && AjaxData.content.action
                    && $.each(AjaxData.content.action, function (key, data) {
                        if (data.mode && data.mode == 'wppdf-generate' && data.filename && data.content) {
                            VT.printPDF.init(data.filename, data.content.replace(/(\r\n|\n|\r)/gm, ""));
                        }
                    });
            }
        });

})(jQuery);