<?php

/**
 * Class for storing font icon library.
 * This is created this way so other VTCore related
 * plugin can utilize a central font icon library.
 *
 * @author jason.xie@victheme.com
 */
class VTCore_Wordpress_Data_Icons_Library
    extends VTCore_Wordpress_Models_Dot
{

    /**
     * Construct the object.
     * Pass in the array to be stored in the object and
     * act as the target for object operations
     *
     * Icon Library array structure:
     * family     : The font icon unique family name
     * text       : Human text to display when used in form elements
     * version    : the stored icon version number
     * asset      : VTCore assets library name to load this font icon asset
     * iconset    : array of all available icon name without prefix
     * base       : the css class base name for this icon set
     * prefix     : the css class prefix name for this icon set
     * element    : valid html that can be used for this icon set.
     *
     * @param array $options
     */
    public function __construct($options = array())
    {

        $this->options = array(
            'fontawesome' => array(
                'family' => 'fontawesome',
                'text' => __('Font Awesome', 'victheme_core'),
                'version' => '4.2.0',
                'asset' => 'font-awesome',
                'url' => VTCore_Wordpress_Init::getFactory('assets')->get('library')->get('font-awesome.css'),
                'iconset' => 'adjust,anchor,archive,area-chart,arrows,arrows-h,arrows-v,asterisk,at,automobile,ban,bank,bar-chart,bar-chart-o,barcode,bars,beer,bell,bell-o,bell-slash,bell-slash-o,bicycle,binoculars,birthday-cake,bolt,bomb,book,bookmark,bookmark-o,briefcase,bug,building,building-o,bullhorn,bullseye,bus,cab,calculator,calendar,calendar-o,camera,camera-retro,car,caret-square-o-down,caret-square-o-left,caret-square-o-right,caret-square-o-up,cc,certificate,check,check-circle,check-circle-o,check-square,check-square-o,child,circle,circle-o,circle-o-notch,circle-thin,clock-o,close,cloud,cloud-download,cloud-upload,code,code-fork,coffee,cog,cogs,comment,comment-o,comments,comments-o,compass,copyright,credit-card,crop,crosshairs,cube,cubes,cutlery,dashboard,database,desktop,dot-circle-o,download,edit,ellipsis-h,ellipsis-v,envelope,envelope-o,envelope-square,eraser,exchange,exclamation,exclamation-circle,exclamation-triangle,external-link,external-link-square,eye,eye-slash,eyedropper,fax,female,fighter-jet,file-archive-o,file-audio-o,file-code-o,file-excel-o,file-image-o,file-movie-o,file-pdf-o,file-photo-o,file-picture-o,file-powerpoint-o,file-sound-o,file-video-o,file-word-o,file-zip-o,film,filter,fire,fire-extinguisher,flag,flag-checkered,flag-o,flash,flask,folder,folder-o,folder-open,folder-open-o,frown-o,futbol-o,gamepad,gavel,gear,gears,gift,glass,globe,graduation-cap,group,hdd-o,headphones,heart,heart-o,history,home,image,inbox,info,info-circle,institution,key,keyboard-o,language,laptop,leaf,legal,lemon-o,level-down,level-up,life-bouy,life-buoy,life-ring,life-saver,lightbulb-o,line-chart,location-arrow,lock,magic,magnet,mail-forward,mail-reply,mail-reply-all,male,map-marker,meh-o,microphone,microphone-slash,minus,minus-circle,minus-square,minus-square-o,mobile,mobile-phone,money,moon-o,mortar-board,music,navicon,newspaper-o,paint-brush,paper-plane,paper-plane-o,paw,pencil,pencil-square,pencil-square-o,phone,phone-square,photo,picture-o,pie-chart,plane,plug,plus,plus-circle,plus-square,plus-square-o,power-off,print,puzzle-piece,qrcode,question,question-circle,quote-left,quote-right,random,recycle,refresh,remove,reorder,reply,reply-all,retweet,road,rocket,rss,rss-square,search,search-minus,search-plus,send,send-o,share,share-alt,share-alt-square,share-square,share-square-o,shield,shopping-cart,sign-in,sign-out,signal,sitemap,sliders,smile-o,soccer-ball-o,sort,sort-alpha-asc,sort-alpha-desc,sort-amount-asc,sort-amount-desc,sort-asc,sort-desc,sort-down,sort-numeric-asc,sort-numeric-desc,sort-up,space-shuttle,spinner,spoon,square,square-o,star,star-half,star-half-empty,star-half-full,star-half-o,star-o,suitcase,sun-o,support,tablet,tachometer,tag,tags,tasks,taxi,terminal,thumb-tack,thumbs-down,thumbs-o-down,thumbs-o-up,thumbs-up,ticket,times,times-circle,times-circle-o,tint,toggle-down,toggle-left,toggle-off,toggle-on,toggle-right,toggle-up,trash,trash-o,tree,trophy,truck,tty,umbrella,university,unlock,unlock-alt,unsorted,upload,user,users,video-camera,volume-down,volume-off,volume-up,warning,wheelchair,wifi,wrench,file,file-o,file-text,file-text-o,cc-amex,cc-discover,cc-mastercard,cc-paypal,cc-stripe,cc-visa,google-wallet,paypal,bitcoin,btc,cny,dollar,eur,euro,gbp,ils,inr,jpy,krw,rmb,rouble,rub,ruble,rupee,shekel,sheqel,try,turkish-lira,usd,won,yen,align-center,align-justify,align-left,align-right,bold,chain,chain-broken,clipboard,columns,copy,cut,dedent,files-o,floppy-o,font,header,indent,italic,link,list,list-alt,list-ol,list-ul,outdent,paperclip,paragraph,paste,repeat,rotate-left,rotate-right,save,scissors,strikethrough,subscript,superscript,table,text-height,text-width,th,th-large,th-list,underline,undo,unlink,angle-double-down,angle-double-left,angle-double-right,angle-double-up,angle-down,angle-left,angle-right,angle-up,arrow-circle-down,arrow-circle-left,arrow-circle-o-down,arrow-circle-o-left,arrow-circle-o-right,arrow-circle-o-up,arrow-circle-right,arrow-circle-up,arrow-down,arrow-left,arrow-right,arrow-up,arrows-alt,caret-down,caret-left,caret-right,caret-up,chevron-circle-down,chevron-circle-left,chevron-circle-right,chevron-circle-up,chevron-down,chevron-left,chevron-right,chevron-up,hand-o-down,hand-o-left,hand-o-right,hand-o-up,long-arrow-down,long-arrow-left,long-arrow-right,long-arrow-up,backward,compress,eject,expand,fast-backward,fast-forward,forward,pause,play,play-circle,play-circle-o,step-backward,step-forward,stop,youtube-play,adn,android,angellist,apple,behance,behance-square,bitbucket,bitbucket-square,codepen,css3,delicious,deviantart,digg,dribbble,dropbox,drupal,empire,facebook,facebook-square,flickr,foursquare,ge,git,git-square,github,github-alt,github-square,gittip,google,google-plus,google-plus-square,hacker-news,html5,instagram,ioxhost,joomla,jsfiddle,lastfm,lastfm-square,linkedin,linkedin-square,linux,maxcdn,meanpath,openid,pagelines,pied-piper,pied-piper-alt,pinterest,pinterest-square,qq,ra,rebel,reddit,reddit-square,renren,skype,slack,slideshare,soundcloud,spotify,stack-exchange,stack-overflow,steam,steam-square,stumbleupon,stumbleupon-circle,tencent-weibo,trello,tumblr,tumblr-square,twitch,twitter,twitter-square,vimeo-square,vine,vk,wechat,weibo,weixin,windows,wordpress,xing,xing-square,yahoo,yelp,youtube,youtube-square,ambulance,h-square,hospital-o,medkit,stethoscope,user-md',
                'base' => 'fa',
                'prefix' => 'fa-',
                'element' => 'i',
                'enabled' => true,
            ),
            'glyphicon' => array(
                'family' => 'glyphicon',
                'text' => __('Bootstrap Glyphicon', 'victheme_core'),
                'version' => '3.1.1',
                'asset' => 'bootstrap-glyphicon',
                'url' => VTCore_Wordpress_Init::getFactory('assets')->get('library')->get('bootstrap-glyphicon.css'),
                'iconset' => 'asterisk,plus,euro,minus,cloud,envelope,pencil,glass,music,search,heart,star,star-empty,user,film,th-large,th,th-list,ok,remove,zoom-in,zoom-out,off,signal,cog,trash,home,file,time,road,download-alt,download,upload,inbox,play-circle,repeat,refresh,list-alt,lock,flag,headphones,volume-off,volume-down,volume-up,qrcode,barcode,tag,tags,book,bookmark,print,camera,font,bold,italic,text-height,text-width,align-left,align-center,align-right,align-justify,list,indent-left,indent-right,facetime-video,picture,map-marker,adjust,tint,edit,share,check,move,step-backward,fast-backward,backward,play,pause,stop,forward,fast-forward,eject,chevron-left,chevron-right,plus-sign,minus-sign,remove-sign,ok-sign,question-sign,info-sign,screenshot,remove-circle,ok-circle,ban-circle,arrow-left,arrow-right,arrow-up,arrow-down,share-alt,resize-full,resize-small,exclamation-sign,gift,leaf,fire,eye-open,eye-close,warning-sign,plane,calendar,random,comment,magnet,chevron-up,chevron-down,retweet,shopping-cart,folder-close,folder-open,resize-vertical,resize-horizontal,hdd,bullhorn,bell,certificate,thumbs-up,thumbs-down,hand-right,hand-left,hand-up,hand-down,circle-arrow-right,circle-arrow-left,circle-arrow-up,circle-arrow-down,globe,wrench,tasks,filter,briefcase,fullscreen,dashboard,paperclip,heart-empty,link,phone,pushpin,usd,gbp,sort,sort-by-alphabet,sort-by-alphabet-alt,sort-by-order,sort-by-order-alt,sort-by-attributes,sort-by-attributes-alt,unchecked,expand,collapse-down,collapse-up,log-in,flash,log-out,new-window,record,save,open,saved,import,export,send,floppy-disk,floppy-saved,floppy-remove,floppy-save,floppy-open,credit-card,transfer,cutlery,header,compressed,earphone,phone-alt,tower,stats,sd-video,hd-video,subtitles,sound-stereo,sound-dolby,sound-5-1,sound-6-1,sound-7-1,copyright-mark,registration-mark,cloud-download,cloud-upload,tree-conifer,tree-deciduous',
                'base' => 'glyphicon',
                'prefix' => 'glyphicon-',
                'element' => 'span',
                'enabled' => true,
            ),
            'eleganticon' => array(
                'family' => 'eleganticon',
                'text' => __('Elegant Icon', 'victheme_core'),
                'version' => '',
                'asset' => 'icon-eleganticon',
                'url' => VTCore_Wordpress_Init::getFactory('assets')->get('library')->get('icon-eleganticon.css'),
                'iconset' => 'arrow_up,arrow_up,arrow_down,arrow_down,arrow_left,arrow_left,arrow_right,arrow_right,arrow_left-up,arrow_left-up,arrow_right-up,arrow_right-up,arrow_right-down,arrow_right-down,arrow_left-down,arrow_left-down,arrow-up-down,arrow-up-down,arrow_up-down_alt,arrow_up-down_alt,arrow_left-right_alt,arrow_left-right_alt,arrow_left-right,arrow_left-right,arrow_expand_alt2,arrow_expand_alt2,arrow_expand_alt,arrow_expand_alt,arrow_condense,arrow_condense,arrow_expand,arrow_expand,arrow_move,arrow_move,arrow_carrot-up,arrow_carrot-up,arrow_carrot-down,arrow_carrot-down,arrow_carrot-left,arrow_carrot-left,arrow_carrot-right,arrow_carrot-right,arrow_carrot-2up,arrow_carrot-2up,arrow_carrot-2down,arrow_carrot-2down,arrow_carrot-2left,arrow_carrot-2left,arrow_carrot-2right,arrow_carrot-2right,arrow_carrot-up_alt2,arrow_carrot-up_alt2,arrow_carrot-down_alt2,arrow_carrot-down_alt2,arrow_carrot-left_alt2,arrow_carrot-left_alt2,arrow_carrot-right_alt2,arrow_carrot-right_alt2,arrow_carrot-2up_alt2,arrow_carrot-2up_alt2,arrow_carrot-2down_alt2,arrow_carrot-2down_alt2,arrow_carrot-2left_alt2,arrow_carrot-2left_alt2,arrow_carrot-2right_alt2,arrow_carrot-2right_alt2,arrow_triangle-up,arrow_triangle-up,arrow_triangle-down,arrow_triangle-down,arrow_triangle-left,arrow_triangle-left,arrow_triangle-right,arrow_triangle-right,arrow_triangle-up_alt2,arrow_triangle-up_alt2,arrow_triangle-down_alt2,arrow_triangle-down_alt2,arrow_triangle-left_alt2,arrow_triangle-left_alt2,arrow_triangle-right_alt2,arrow_triangle-right_alt2,arrow_back,arrow_back,icon_minus-06,icon_minus-06,icon_plus,icon_plus,icon_close,icon_close,icon_check,icon_check,icon_minus_alt2,icon_minus_alt2,icon_plus_alt2,icon_plus_alt2,icon_close_alt2,icon_close_alt2,icon_check_alt2,icon_check_alt2,icon_zoom-out_alt,icon_zoom-out_alt,icon_zoom-in_alt,icon_zoom-in_alt,icon_search,icon_search,icon_box-empty,icon_box-empty,icon_box-selected,icon_box-selected,icon_minus-box,icon_minus-box,icon_plus-box,icon_plus-box,icon_box-checked,icon_box-checked,icon_circle-empty,icon_circle-empty,icon_circle-slelected,icon_circle-slelected,icon_stop_alt2,icon_stop_alt2,icon_stop,icon_stop,icon_pause_alt2,icon_pause_alt2,icon_pause,icon_pause,icon_menu,icon_menu,icon_menu-square_alt2,icon_menu-square_alt2,icon_menu-circle_alt2,icon_menu-circle_alt2,icon_ul,icon_ul,icon_ol,icon_ol,icon_adjust-horiz,icon_adjust-horiz,icon_adjust-vert,icon_adjust-vert,icon_document_alt,icon_document_alt,icon_documents_alt,icon_documents_alt,icon_pencil,icon_pencil,icon_pencil-edit_alt,icon_pencil-edit_alt,icon_pencil-edit,icon_pencil-edit,icon_folder-alt,icon_folder-alt,icon_folder-open_alt,icon_folder-open_alt,icon_folder-add_alt,icon_folder-add_alt,icon_info_alt,icon_info_alt,icon_error-oct_alt,icon_error-oct_alt,icon_error-circle_alt,icon_error-circle_alt,icon_error-triangle_alt,icon_error-triangle_alt,icon_question_alt2,icon_question_alt2,icon_question,icon_question,icon_comment_alt,icon_comment_alt,icon_chat_alt,icon_chat_alt,icon_vol-mute_alt,icon_vol-mute_alt,icon_volume-low_alt,icon_volume-low_alt,icon_volume-high_alt,icon_volume-high_alt,icon_quotations,icon_quotations,icon_quotations_alt2,icon_quotations_alt2,icon_clock_alt,icon_clock_alt,icon_lock_alt,icon_lock_alt,icon_lock-open_alt,icon_lock-open_alt,icon_key_alt,icon_key_alt,icon_cloud_alt,icon_cloud_alt,icon_cloud-upload_alt,icon_cloud-upload_alt,icon_cloud-download_alt,icon_cloud-download_alt,icon_image,icon_image,icon_images,icon_images,icon_lightbulb_alt,icon_lightbulb_alt,icon_gift_alt,icon_gift_alt,icon_house_alt,icon_house_alt,icon_genius,icon_genius,icon_mobile,icon_mobile,icon_tablet,icon_tablet,icon_laptop,icon_laptop,icon_desktop,icon_desktop,icon_camera_alt,icon_camera_alt,icon_mail_alt,icon_mail_alt,icon_cone_alt,icon_cone_alt,icon_ribbon_alt,icon_ribbon_alt,icon_bag_alt,icon_bag_alt,icon_creditcard,icon_creditcard,icon_cart_alt,icon_cart_alt,icon_paperclip,icon_paperclip,icon_tag_alt,icon_tag_alt,icon_tags_alt,icon_tags_alt,icon_trash_alt,icon_trash_alt,icon_cursor_alt,icon_cursor_alt,icon_mic_alt,icon_mic_alt,icon_compass_alt,icon_compass_alt,icon_pin_alt,icon_pin_alt,icon_pushpin_alt,icon_pushpin_alt,icon_map_alt,icon_map_alt,icon_drawer_alt,icon_drawer_alt,icon_toolbox_alt,icon_toolbox_alt,icon_book_alt,icon_book_alt,icon_calendar,icon_calendar,icon_film,icon_film,icon_table,icon_table,icon_contacts_alt,icon_contacts_alt,icon_headphones,icon_headphones,icon_lifesaver,icon_lifesaver,icon_piechart,icon_piechart,icon_refresh,icon_refresh,icon_link_alt,icon_link_alt,icon_link,icon_link,icon_loading,icon_loading,icon_blocked,icon_blocked,icon_archive_alt,icon_archive_alt,icon_heart_alt,icon_heart_alt,icon_printer,icon_printer,icon_calulator,icon_calulator,icon_building,icon_building,icon_floppy,icon_floppy,icon_drive,icon_drive,icon_search-2,icon_search-2,icon_id,icon_id,icon_id-2,icon_id-2,icon_puzzle,icon_puzzle,icon_like,icon_like,icon_dislike,icon_dislike,icon_mug,icon_mug,icon_currency,icon_currency,icon_wallet,icon_wallet,icon_pens,icon_pens,icon_easel,icon_easel,icon_flowchart,icon_flowchart,icon_datareport,icon_datareport,icon_briefcase,icon_briefcase,icon_shield,icon_shield,icon_percent,icon_percent,icon_globe,icon_globe,icon_globe-2,icon_globe-2,icon_target,icon_target,icon_hourglass,icon_hourglass,icon_balance,icon_balance,icon_star_alt,icon_star_alt,icon_star-half_alt,icon_star-half_alt,icon_star,icon_star,icon_star-half,icon_star-half,icon_tools,icon_tools,icon_tool,icon_tool,icon_cog,icon_cog,icon_cogs,icon_cogs,arrow_up_alt,arrow_up_alt,arrow_down_alt,arrow_down_alt,arrow_left_alt,arrow_left_alt,arrow_right_alt,arrow_right_alt,arrow_left-up_alt,arrow_left-up_alt,arrow_right-up_alt,arrow_right-up_alt,arrow_right-down_alt,arrow_right-down_alt,arrow_left-down_alt,arrow_left-down_alt,arrow_condense_alt,arrow_condense_alt,arrow_expand_alt3,arrow_expand_alt3,arrow_carrot_up_alt,arrow_carrot_up_alt,arrow_carrot-down_alt,arrow_carrot-down_alt,arrow_carrot-left_alt,arrow_carrot-left_alt,arrow_carrot-right_alt,arrow_carrot-right_alt,arrow_carrot-2up_alt,arrow_carrot-2up_alt,arrow_carrot-2dwnn_alt,arrow_carrot-2dwnn_alt,arrow_carrot-2left_alt,arrow_carrot-2left_alt,arrow_carrot-2right_alt,arrow_carrot-2right_alt,arrow_triangle-up_alt,arrow_triangle-up_alt,arrow_triangle-down_alt,arrow_triangle-down_alt,arrow_triangle-left_alt,arrow_triangle-left_alt,arrow_triangle-right_alt,arrow_triangle-right_alt,icon_minus_alt,icon_minus_alt,icon_plus_alt,icon_plus_alt,icon_close_alt,icon_close_alt,icon_check_alt,icon_check_alt,icon_zoom-out,icon_zoom-out,icon_zoom-in,icon_zoom-in,icon_stop_alt,icon_stop_alt,icon_menu-square_alt,icon_menu-square_alt,icon_menu-circle_alt,icon_menu-circle_alt,icon_document,icon_document,icon_documents,icon_documents,icon_pencil_alt,icon_pencil_alt,icon_folder,icon_folder,icon_folder-open,icon_folder-open,icon_folder-add,icon_folder-add,icon_folder_upload,icon_folder_upload,icon_folder_download,icon_folder_download,icon_info,icon_info,icon_error-circle,icon_error-circle,icon_error-oct,icon_error-oct,icon_error-triangle,icon_error-triangle,icon_question_alt,icon_question_alt,icon_comment,icon_comment,icon_chat,icon_chat,icon_vol-mute,icon_vol-mute,icon_volume-low,icon_volume-low,icon_volume-high,icon_volume-high,icon_quotations_alt,icon_quotations_alt,icon_clock,icon_clock,icon_lock,icon_lock,icon_lock-open,icon_lock-open,icon_key,icon_key,icon_cloud,icon_cloud,icon_cloud-upload,icon_cloud-upload,icon_cloud-download,icon_cloud-download,icon_lightbulb,icon_lightbulb,icon_gift,icon_gift,icon_house,icon_house,icon_camera,icon_camera,icon_mail,icon_mail,icon_cone,icon_cone,icon_ribbon,icon_ribbon,icon_bag,icon_bag,icon_cart,icon_cart,icon_tag,icon_tag,icon_tags,icon_tags,icon_trash,icon_trash,icon_cursor,icon_cursor,icon_mic,icon_mic,icon_compass,icon_compass,icon_pin,icon_pin,icon_pushpin,icon_pushpin,icon_map,icon_map,icon_drawer,icon_drawer,icon_toolbox,icon_toolbox,icon_book,icon_book,icon_contacts,icon_contacts,icon_archive,icon_archive,icon_heart,icon_heart,icon_profile,icon_profile,icon_group,icon_group,icon_grid-2x2,icon_grid-3x3,icon_music,icon_music,icon_pause_alt,icon_pause_alt,icon_phone,icon_phone,icon_upload,icon_upload,icon_download,icon_download,icon_rook,icon_rook,icon_printer-alt,icon_printer-alt,icon_calculator_alt,icon_calculator_alt,icon_building_alt,icon_building_alt,icon_floppy_alt,icon_floppy_alt,icon_drive_alt,icon_drive_alt,icon_search_alt,icon_search_alt,icon_id_alt,icon_id_alt,icon_id-2_alt,icon_id-2_alt,icon_puzzle_alt,icon_puzzle_alt,icon_like_alt,icon_like_alt,icon_dislike_alt,icon_dislike_alt,icon_mug_alt,icon_mug_alt,icon_currency_alt,icon_currency_alt,icon_wallet_alt,icon_wallet_alt,icon_pens_alt,icon_pens_alt,icon_easel_alt,icon_easel_alt,icon_flowchart_alt,icon_flowchart_alt,icon_datareport_alt,icon_datareport_alt,icon_briefcase_alt,icon_briefcase_alt,icon_shield_alt,icon_shield_alt,icon_percent_alt,icon_percent_alt,icon_globe_alt,icon_globe_alt,icon_clipboard,icon_clipboard,social_facebook,social_facebook,social_twitter,social_twitter,social_pinterest,social_pinterest,social_googleplus,social_googleplus,social_tumblr,social_tumblr,social_tumbleupon,social_tumbleupon,social_wordpress,social_wordpress,social_instagram,social_instagram,social_dribbble,social_dribbble,social_vimeo,social_vimeo,social_linkedin,social_linkedin,social_rss,social_rss,social_deviantart,social_deviantart,social_share,social_share,social_myspace,social_myspace,social_skype,social_skype,social_youtube,social_youtube,social_picassa,social_picassa,social_googledrive,social_googledrive,social_flickr,social_flickr,social_blogger,social_blogger,social_spotify,social_spotify,social_delicious,social_delicious,social_facebook_circle,social_facebook_circle,social_twitter_circle,social_twitter_circle,social_pinterest_circle,social_pinterest_circle,social_googleplus_circle,social_googleplus_circle,social_tumblr_circle,social_tumblr_circle,social_stumbleupon_circle,social_stumbleupon_circle,social_wordpress_circle,social_wordpress_circle,social_instagram_circle,social_instagram_circle,social_dribbble_circle,social_dribbble_circle,social_vimeo_circle,social_vimeo_circle,social_linkedin_circle,social_linkedin_circle,social_rss_circle,social_rss_circle,social_deviantart_circle,social_deviantart_circle,social_share_circle,social_share_circle,social_myspace_circle,social_myspace_circle,social_skype_circle,social_skype_circle,social_youtube_circle,social_youtube_circle,social_picassa_circle,social_picassa_circle,social_googledrive_alt2,social_googledrive_alt2,social_flickr_circle,social_flickr_circle,social_blogger_circle,social_blogger_circle,social_spotify_circle,social_spotify_circle,social_delicious_circle,social_delicious_circle,social_facebook_square,social_facebook_square,social_twitter_square,social_twitter_square,social_pinterest_square,social_pinterest_square,social_googleplus_square,social_googleplus_square,social_tumblr_square,social_tumblr_square,social_stumbleupon_square,social_stumbleupon_square,social_wordpress_square,social_wordpress_square,social_instagram_square,social_instagram_square,social_dribbble_square,social_dribbble_square,social_vimeo_square,social_vimeo_square,social_linkedin_square,social_linkedin_square,social_rss_square,social_rss_square,social_deviantart_square,social_deviantart_square,social_share_square,social_share_square,social_myspace_square,social_myspace_square,social_skype_square,social_skype_square,social_youtube_square,social_youtube_square,social_picassa_square,social_picassa_square,social_googledrive_square,social_googledrive_square,social_flickr_square,social_flickr_square,social_blogger_square,social_blogger_square,social_spotify_square,social_spotify_square,social_delicious_square,social_delicious_square',
                'base' => 'eleicon',
                'prefix' => 'eleicon-',
                'element' => 'i',
                'enabled' => true,
            ),
            'foundation' => array(
                'family' => 'foundation',
                'text' => __('Foundation', 'victheme_core'),
                'version' => '3.0',
                'asset' => 'icon-foundation',
                'url' => VTCore_Wordpress_Init::getFactory('assets')->get('library')->get('icon-foundation.css'),
                'iconset' => 'address-book,alert,align-center,align-justify,align-left,align-right,anchor,annotate,archive,arrow-down,arrow-left,arrow-right,arrow-up,arrows-compress,arrows-expand,arrows-in,arrows-out,asl,asterisk,at-sign,background-color,battery-empty,battery-full,battery-half,bitcoin-circle,bitcoin,blind,bluetooth,bold,book-bookmark,book,bookmark,braille,burst-new,burst-sale,burst,calendar,camera,check,checkbox,clipboard-notes,clipboard-pencil,clipboard,clock,closed-caption,cloud,comment-minus,comment-quotes,comment-video,comment,comments,compass,contrast,credit-card,crop,crown,css3,database,die-five,die-four,die-one,die-six,die-three,die-two,dislike,dollar-bill,dollar,download,eject,elevator,euro,eye,fast-forward,female-symbol,female,filter,first-aid,flag,folder-add,folder-lock,folder,foot,foundation,graph-bar,graph-horizontal,graph-pie,graph-trend,guide-dog,hearing-aid,heart,home,html5,indent-less,indent-more,info,italic,key,laptop,layout,lightbulb,like,link,list-bullet,list-number,list-thumbnails,list,lock,loop,magnifying-glass,mail,male-female,male-symbol,male,map,marker,megaphone,microphone,minus-circle,minus,mobile-signal,mobile,monitor,mountains,music,next,no-dogs,no-smoking,page-add,page-copy,page-csv,page-delete,page-doc,page-edit,page-export-csv,page-export-doc,page-export-pdf,page-export,page-filled,page-multiple,page-pdf,page-remove,page-search,page,paint-bucket,paperclip,pause,paw,paypal,pencil,photo,play-circle,play-video,play,plus,pound,power,previous,price-tag,pricetag-multiple,print,prohibited,projection-screen,puzzle,quote,record,refresh,results-demographics,results,rewind-ten,rewind,rss,safety-cone,save,share,sheriff-badge,shield,shopping-bag,shopping-cart,shuffle,skull,social-500px,social-adobe,social-amazon,social-android,social-apple,social-behance,social-bing,social-blogger,social-delicious,social-designer-news,social-deviant-art,social-digg,social-dribbble,social-drive,social-dropbox,social-evernote,social-facebook,social-flickr,social-forrst,social-foursquare,social-game-center,social-github,social-google-plus,social-hacker-news,social-hi5,social-instagram,social-joomla,social-lastfm,social-linkedin,social-medium,social-myspace,social-orkut,social-path,social-picasa,social-pinterest,social-rdio,social-reddit,social-skillshare,social-skype,social-smashing-mag,social-snapchat,social-spotify,social-squidoo,social-stack-overflow,social-steam,social-stumbleupon,social-treehouse,social-tumblr,social-twitter,social-vimeo,social-windows,social-xbox,social-yahoo,social-yelp,social-youtube,social-zerply,social-zurb,sound,star,stop,strikethrough,subscript,superscript,tablet-landscape,tablet-portrait,target-two,target,telephone-accessible,telephone,text-color,thumbnails,ticket,torso-business,torso-female,torso,torsos-all-female,torsos-all,torsos-female-male,torsos-male-female,torsos,trash,trees,trophy,underline,universal-access,unlink,unlock,upload-cloud,upload,usb,video,volume-none,volume-strike,volume,web,wheelchair,widget,wrench,x-circle,x,yen,zoom-in,zoom-out',
                'base' => ' ',
                'prefix' => 'fi-',
                'element' => 'i',
                'enabled' => true,
            ),
            'typicons' => array(
                'family' => 'typicons',
                'text' => __('Typicons', 'victheme_core'),
                'version' => '2.0.7',
                'asset' => 'icon-typicons',
                'url' => VTCore_Wordpress_Init::getFactory('assets')->get('library')->get('icon-typicons.css'),
                'iconset' => 'adjust-brightness,adjust-contrast,anchor-outline,anchor,archive,arrow-back-outline,arrow-back,arrow-down-outline,arrow-down-thick,arrow-down,arrow-forward-outline,arrow-forward,arrow-left-outline,arrow-left-thick,arrow-left,arrow-loop-outline,arrow-loop,arrow-maximise-outline,arrow-maximise,arrow-minimise-outline,arrow-minimise,arrow-move-outline,arrow-move,arrow-repeat-outline,arrow-repeat,arrow-right-outline,arrow-right-thick,arrow-right,arrow-shuffle,arrow-sorted-down,arrow-sorted-up,arrow-sync-outline,arrow-sync,arrow-unsorted,arrow-up-outline,arrow-up-thick,arrow-up,at,attachment-outline,attachment,backspace-outline,backspace,battery-charge,battery-full,battery-high,battery-low,battery-mid,beaker,beer,bell,book,bookmark,briefcase,brush,business-card,calculator,calendar-outline,calendar,camera-outline,camera,cancel-outline,cancel,chart-area-outline,chart-area,chart-bar-outline,chart-bar,chart-line-outline,chart-line,chart-pie-outline,chart-pie,chevron-left-outline,chevron-left,chevron-right-outline,chevron-right,clipboard,cloud-storage,cloud-storage-outline,code-outline,code,coffee,cog-outline,cog,compass,contacts,credit-card,css3,database,delete-outline,delete,device-desktop,device-laptop,device-phone,device-tablet,directions,divide-outline,divide,document-add,document-delete,document-text,document,download-outline,download,dropbox,edit,eject-outline,eject,equals-outline,equals,export-outline,export,eye-outline,eye,feather,film,filter,flag-outline,flag,flash-outline,flash,flow-children,flow-merge,flow-parallel,flow-switch,folder-add,folder-delete,folder-open,folder,gift,globe-outline,globe,group-outline,group,headphones,heart-full-outline,heart-half-outline,heart-outline,heart,home-outline,home,html5,image-outline,image,infinity-outline,infinity,info-large-outline,info-large,info-outline,info,input-checked-outline,input-checked,key-outline,key,keyboard,leaf,lightbulb,link-outline,link,location-arrow-outline,location-arrow,location-outline,location,lock-closed-outline,lock-closed,lock-open-outline,lock-open,mail,map,media-eject-outline,media-eject,media-fast-forward-outline,media-fast-forward,media-pause-outline,media-pause,media-play-outline,media-play-reverse-outline,media-play-reverse,media-play,media-record-outline,media-record,media-rewind-outline,media-rewind,media-stop-outline,media-stop,message-typing,message,messages,microphone-outline,microphone,minus-outline,minus,mortar-board,news,notes-outline,notes,pen,pencil,phone-outline,phone,pi-outline,pi,pin-outline,pin,pipette,plane-outline,plane,plug,plus-outline,plus,point-of-interest-outline,point-of-interest,power-outline,power,printer,puzzle-outline,puzzle,radar-outline,radar,refresh-outline,refresh,rss-outline,rss,scissors-outline,scissors,shopping-bag,shopping-cart,social-at-circular,social-dribbble-circular,social-dribbble,social-facebook-circular,social-facebook,social-flickr-circular,social-flickr,social-github-circular,social-github,social-google-plus-circular,social-google-plus,social-instagram-circular,social-instagram,social-last-fm-circular,social-last-fm,social-linkedin-circular,social-linkedin,social-pinterest-circular,social-pinterest,social-skype-outline,social-skype,social-tumbler-circular,social-tumbler,social-twitter-circular,social-twitter,social-vimeo-circular,social-vimeo,social-youtube-circular,social-youtube,sort-alphabetically-outline,sort-alphabetically,sort-numerically-outline,sort-numerically,spanner-outline,spanner,spiral,star-full-outline,star-half-outline,star-half,star-outline,star,starburst-outline,starburst,stopwatch,support,tabs-outline,tag,tags,th-large-outline,th-large,th-list-outline,th-list,th-menu-outline,th-menu,th-small-outline,th-small,thermometer,thumbs-down,thumbs-ok,thumbs-up,tick-outline,tick,ticket,time,times-outline,times,trash,tree,upload-outline,upload,user-add-outline,user-add,user-delete-outline,user-delete,user-outline,user,vendor-android,vendor-apple,vendor-microsoft,video-outline,video,volume-down,volume-mute,volume-up,volume,warning-outline,warning,watch,waves-outline,waves,weather-cloudy,weather-downpour,weather-night,weather-partly-sunny,weather-shower,weather-snow,weather-stormy,weather-sunny,weather-windy-cloudy,weather-windy,wi-fi-outline,wi-fi,wine,world-outline,world,zoom-in-outline,zoom-in,zoom-out-outline,zoom-out,zoom-outline,zoom',
                'base' => 'typcn',
                'prefix' => 'typcn-',
                'element' => 'i',
                'enabled' => true,
            ),
            'iconic' => array(
                'family' => 'openiconic',
                'text' => __('Open Iconic', 'victheme_core'),
                'version' => '1.1.1',
                'asset' => 'icon-open-iconic',
                'url' => VTCore_Wordpress_Init::getFactory('assets')->get('library')->get('icon-open-iconic.css'),
                'iconset' => 'account-login,account-logout,action-redo,action-undo,align-center,align-left,align-right,aperture,arrow-bottom,arrow-circle-bottom,arrow-circle-left,arrow-circle-right,arrow-circle-top,arrow-left,arrow-right,arrow-thick-bottom,arrow-thick-left,arrow-thick-right,arrow-thick-top,arrow-top,audio-spectrum,audio,badge,ban,bar-chart,basket,battery-empty,battery-full,beaker,bell,bluetooth,bold,bolt,book,bookmark,box,briefcase,british-pound,browser,brush,bug,bullhorn,calculator,calendar,camera-slr,caret-bottom,caret-left,caret-right,caret-top,cart,chat,check,chevron-bottom,chevron-left,chevron-right,chevron-top,circle-check,circle-x,clipboard,clock,cloud-download,cloud-upload,cloud,cloudy,code,cog,collapse-down,collapse-left,collapse-right,collapse-up,command,comment-square,compass,contrast,copywriting,credit-card,crop,dashboard,data-transfer-download,data-transfer-upload,delete,dial,document,dollar,double-quote-sans-left,double-quote-sans-right,double-quote-serif-left,double-quote-serif-right,droplet,eject,elevator,ellipses,envelope-closed,envelope-open,euro,excerpt,expand-down,expand-left,expand-right,expand-up,external-link,eye,eyedropper,file,fire,flag,flash,folder,fork,fullscreen-enter,fullscreen-exit,globe,graph,grid-four-up,grid-three-up,grid-two-up,hard-drive,header,headphones,heart,home,image,inbox,infinity,info,italic,justify-center,justify-left,justify-right,key,laptop,layers,lightbulb,link-broken,link-intact,list-rich,list,location,lock-locked,lock-unlocked,loop-circular,loop-square,loop,magnifying-glass,map-marker,map,media-pause,media-play,media-record,media-skip-backward,media-skip-forward,media-step-backward,media-step-forward,media-stop,medical-cross,menu,microphone,minus,monitor,moon,move,musical-note,paperclip,pencil,people,person,phone,pie-chart,pin,play-circle,plus,power-standby,print,project,pulse,puzzle-piece,question-mark,rain,random,reload,resize-both,resize-height,resize-width,rss-alt,rss,script,share-boxed,share,shield,signal,signpost,sort-ascending,sort-descending,spreadsheet,star,sun,tablet,tag,tags,target,task,terminal,text,thumb-down,thumb-up,timer,transfer,trash,underline,vertical-align-bottom,vertical-align-center,vertical-align-top,video,volume-high,volume-low,volume-off,warning,wifi,wrench,x,yen,zoom-in,zoom-out',
                'base' => 'oi',
                'prefix' => 'oi-',
                'element' => 'i',
                'enabled' => true,
            ),
            'entypo' => array(
                'family' => 'entypo',
                'text' => __('Entypo', 'victheme_core'),
                'version' => '',
                'asset' => 'icon-entypo',
                'url' => VTCore_Wordpress_Init::getFactory('assets')->get('library')->get('icon-entypo.css'),
                'iconset' => 'icon-note,icon-note-beamed,icon-music,icon-search,icon-flashlight,icon-mail,icon-heart,icon-heart-empty,icon-star,icon-star-empty,icon-user,icon-users,icon-user-add,icon-video,icon-picture,icon-camera,icon-layout,icon-menu,icon-check,icon-cancel,icon-cancel-circled,icon-cancel-squared,icon-plus,icon-plus-circled,icon-plus-squared,icon-minus,icon-minus-circled,icon-minus-squared,icon-help,icon-help-circled,icon-info,icon-info-circled,icon-back,icon-home,icon-link,icon-attach,icon-lock,icon-lock-open,icon-eye,icon-tag,icon-bookmark,icon-bookmarks,icon-flag,icon-thumbs-up,icon-thumbs-down,icon-download,icon-upload,icon-upload-cloud,icon-reply,icon-reply-all,icon-forward,icon-quote,icon-code,icon-export,icon-pencil,icon-feather,icon-print,icon-retweet,icon-keyboard,icon-comment,icon-chat,icon-bell,icon-attention,icon-alert,icon-vcard,icon-address,icon-location,icon-map,icon-direction,icon-compass,icon-cup,icon-trash,icon-doc,icon-docs,icon-doc-landscape,icon-doc-text,icon-doc-text-inv,icon-newspaper,icon-book-open,icon-book,icon-folder,icon-archive,icon-box,icon-rss,icon-phone,icon-cog,icon-tools,icon-share,icon-shareable,icon-basket,icon-bag,icon-calendar,icon-login,icon-logout,icon-mic,icon-mute,icon-sound,icon-volume,icon-clock,icon-hourglass,icon-lamp,icon-light-down,icon-light-up,icon-adjust,icon-block,icon-resize-full,icon-resize-small,icon-popup,icon-publish,icon-window,icon-arrow-combo,icon-down-circled,icon-left-circled,icon-right-circled,icon-up-circled,icon-down-open,icon-left-open,icon-right-open,icon-up-open,icon-down-open-mini,icon-left-open-mini,icon-right-open-mini,icon-up-open-mini,icon-down-open-big,icon-left-open-big,icon-right-open-big,icon-up-open-big,icon-down,icon-left,icon-right,icon-up,icon-down-dir,icon-left-dir,icon-right-dir,icon-up-dir,icon-down-bold,icon-left-bold,icon-right-bold,icon-up-bold,icon-down-thin,icon-left-thin,icon-right-thin,icon-up-thin,icon-ccw,icon-cw,icon-arrows-ccw,icon-level-down,icon-level-up,icon-shuffle,icon-loop,icon-switch,icon-play,icon-stop,icon-pause,icon-record,icon-to-end,icon-to-start,icon-fast-forward,icon-fast-backward,icon-progress-0,icon-progress-1,icon-progress-2,icon-progress-3,icon-target,icon-palette,icon-list,icon-list-add,icon-signal,icon-trophy,icon-battery,icon-back-in-time,icon-monitor,icon-mobile,icon-network,icon-cd,icon-inbox,icon-install,icon-globe,icon-cloud,icon-cloud-thunder,icon-flash,icon-moon,icon-flight,icon-paper-plane,icon-leaf,icon-lifebuoy,icon-mouse,icon-briefcase,icon-suitcase,icon-dot,icon-dot-2,icon-dot-3,icon-brush,icon-magnet,icon-infinity,icon-erase,icon-chart-pie,icon-chart-line,icon-chart-bar,icon-chart-area,icon-tape,icon-graduation-cap,icon-language,icon-ticket,icon-water,icon-droplet,icon-air,icon-credit-card,icon-floppy,icon-clipboard,icon-megaphone,icon-database,icon-drive,icon-bucket,icon-thermometer,icon-key,icon-flow-cascade,icon-flow-branch,icon-flow-tree,icon-flow-line,icon-flow-parallel,icon-rocket,icon-gauge,icon-traffic-cone,icon-cc,icon-cc-by,icon-cc-nc,icon-cc-nc-eu,icon-cc-nc-jp,icon-cc-sa,icon-cc-nd,icon-cc-pd,icon-cc-zero,icon-cc-share,icon-cc-remix,icon-github,icon-github-circled,icon-flickr,icon-flickr-circled,icon-vimeo,icon-vimeo-circled,icon-twitter,icon-twitter-circled,icon-facebook,icon-facebook-circled,icon-facebook-squared,icon-gplus,icon-gplus-circled,icon-pinterest,icon-pinterest-circled,icon-tumblr,icon-tumblr-circled,icon-linkedin,icon-linkedin-circled,icon-dribbble,icon-dribbble-circled,icon-stumbleupon,icon-stumbleupon-circled,icon-lastfm,icon-lastfm-circled,icon-rdio,icon-rdio-circled,icon-spotify,icon-spotify-circled,icon-qq,icon-instagrem,icon-dropbox,icon-evernote,icon-flattr,icon-skype,icon-skype-circled,icon-renren,icon-sina-weibo,icon-paypal,icon-picasa,icon-soundcloud,icon-mixi,icon-behance,icon-google-circles,icon-vkontakte,icon-smashing,icon-sweden,icon-db-shape,icon-logo-db',
                'base' => 'entypo',
                'prefix' => 'entypo-',
                'element' => 'i',
                'enabled' => true,
            )
        );

        $this->merge((array)$options);
        $this->sanitizer = new $this->sanitizerClass();

        // Other plugin can register or modify the library here!
        do_action('vtcore_wordpress_alter_icons_library', $this);

        // Other plugin can disable / enable the assets here!
        do_action('vtcore_wordpress_alter_icons_status', $this);

    }

    /**
     * Overridding parent method, we need to check
     * if the icon family is trully enabled or not first
     * before fetching the data.
     *
     * @param $keys
     * @param bool|FALSE $sanitize
     */
    public function get($keys, $sanitize = false)
    {
        if (isset($this->options[$keys]) && !$this->get($keys . '.enabled')) {
            return null;
        }

        return parent::get($keys, $sanitize);
    }

    public function getFontListOptions()
    {
        $options = array(
            false => __('-- Select --', 'victheme_core'),
        );

        foreach ($this->extract() as $family => $data) {

            if (!$this->get($family . '.enabled')) {
                continue;
            }

            if ($this->get($family . '.text')) {
                $options[$family] = $this->get($family . '.text');
            } else {
                $options[$family] = $family;
            }
        }

        return $options;
    }

    public function getAssetsLinks()
    {
        $assets = new VTCore_Wordpress_Objects_Array();
        foreach ($this->extract() as $family => $data) {
            $urls = array();
            if ($data['url']) {
                foreach ($data['url'] as $key => $value) {
                    if ($value['url']) {
                        $urls[] = $value['url'];
                    }
                };
            }

            if (!empty($urls)) {
                $assets->add($family, $urls);
            }
        }

        return $assets->extract();
    }

}