<?php

/**
 * Helper Class for building the TextArea Form Elements
 * with TinyMce
 *
 * @author jason.xie@victheme.com
 */
class VTCore_Wordpress_Form_WpTextarea
    extends VTCore_Bootstrap_Form_BsTextarea
    implements VTCore_Form_Interface
{

    protected $context = array(

        'text' => false,
        'description' => false,
        'required' => false,
        'resizeable' => false,
        'editor' => false,
        'id' => false,
        'class' => array(
            'form-control',
        ),
        'name' => false,
        'cols' => false,
        'rows' => 6,
        'value' => false,

        'label' => true,

        'togglelabel' => false,

        // Wrapper element
        'type' => 'div',
        'attributes' => array(
            'class' => array(
                'form-group',
                'clearfix',
                'wp-tinymce-form-control'
            ),
        ),
        // Internal use, Only override if needed
        'input_elements' => array(),
        'label_elements' => array(),
        'description_elements' => array(),
        'required_elements' => array(),
        'tinymce' => array(
            'wpautoop' => false,
            'media_buttons' => true,
            'textarea_rows' => 10,
            'teeny' => true,
            'quicktags' => true,
            'tinymce' => true,
            'drag_drop_upload' => false,
        )
    );

    protected $input;

    public function buildElement()
    {

        if ($this->getContext('editor')) {
            $this->addContext('input_elements.attributes.id', uniqid('tinymce_'));
        }

        parent::buildElement();

        if ($this->getContext('editor')) {

            wp_enqueue_style('editor-buttons');

            // We need the WP editor js settings injected to each instance, weird but working.
            if (!class_exists('_WP_Editors', false)) {
                require(ABSPATH . WPINC . '/class-wp-editor.php');
            }

            // WP create form tags inside wp link, breaking the form markup!
            add_filter('teeny_mce_plugins', function($opts, $editor_id){
                if ($this->getContext('input_elements.attributes.id') === $editor_id) {
                    foreach($opts as $delta => $value) {
                        if ($value === 'wplink') {
                            unset($opts[$delta]);
                        }
                    }
                }
                return $opts;
            }, 10, 2);

            // WP create form tags inside wp link, breaking the form markup!
            add_filter('quicktags_settings', function($opts, $editor_id){
                if ($this->getContext('input_elements.attributes.id') === $editor_id) {
                    $opts = str_replace('link', '', $opts);
                }
                return $opts;
            }, 10, 2);

            // Get the javascript settings for this editor
            ob_start();
            _WP_Editors::parse_settings($this->getContext('input_elements.attributes.id'), $this->getContext('tinymce'));
            _WP_Editors::editor_settings($this->getContext('input_elements.attributes.id'), $this->getContext('tinymce'));
            _WP_Editors::editor_js();
            _WP_Editors::enqueue_default_editor();

            VTCore_Wordpress_Utility::loadAsset('wp-textarea');

            $settings = ob_get_flush();
            $settings = str_replace('<script type="text/javascript">', '', $settings);
            $settings = explode('</script>', $settings);

            ob_start();
            _WP_Editors::print_tinymce_scripts();
            $tinyscript = ob_get_flush();

            if (!empty($tinyscript)) {
                $this->addChildren(new VTCore_Html_Element(array(
                    'type' => false,
                    'raw' => true,
                    'text' => $tinyscript,
                )));
            }

            $settings[0] .= '
                if (!window.VT) window.VT = {}
                if (!window.VT.WPTextarea) window.VT.WPTextarea = {};
                var elID = "' . $this->getContext('input_elements.attributes.id') . '";
                window.VT.WPTextarea[elID] = {
                    tinymce: tinyMCEPreInit.mceInit[elID],
                    quicktags: tinyMCEPreInit.qtInit[elID]
                }
            ';

            $this
                ->insertChildrenAfter($this->input->getMachineID(), 'tinymce-wrapper', new VTCore_Html_Script(array(
                    'children' => $settings[0],
                    'raw' => true,
                )));

        }
    }

}