/**
 * Simple script for building canvas point
 * arc connector between 2 points
 *
 * markup :
 *
 * container must have position relative rule
 * and css class : point-connector
 * source point must have css class : Point.$start
 * target point must have css class : Point.$end
 *
 * Improved to use multiple canvas for avoiding
 * canvas maximum size limit in browser
 *
 * @author jason.xie@victheme.com
 */
(function ($) {
    
    function HistoryCreatePoints(Points, Point) {
        Point.ctx = Point.$canvas.get(0).getContext('2d');
        Point.point = {
            start: {
                x: Point.$start.offset().left - Point.$canvas.offset().left,
                y: Point.$start.offset().top - Point.$canvas.offset().top
            },
            end: {
                x: Point.$end.length ? Point.$end.offset().left - Point.$canvas.offset().left : 0,
                y: Point.$end.length ? Point.$end.offset().top - Point.$canvas.offset().top : 0
            },
            control: {
                x: 0,
                y: 0
            },
            curve: {
                x: Point.$el.data('curve-x') || Points.$el.data('curvex') || 0,
                y: Point.$el.data('curve-y') || Points.$el.data('curvey') || 100
            },
            offset: {
                start: {
                    x: Point.$el.data('offset-start-x') || Points.$el.data('startx') || Point.$start.width() / 2,
                    y: Point.$el.data('offset-start-y') || Points.$el.data('starty') || Point.$start.height() / 2
                },
                end: {
                    x: Point.$el.data('offset-end-x') || Points.$el.data('endx') || Point.$end.length ? Point.$end.width() / 2 : 0,
                    y: Point.$el.data('offset-end-y') || Points.$el.data('endy') || Point.$end.length ? Point.$end.height() / 2 : 0
                }
            },
            gradient: {
                one: Point.$el.data('gradientone') || Points.$el.data('gradientone') || '#ff6c00',
                two: Point.$el.data('gradienttwo') || Points.$el.data('gradienttwo') || '#1c2232'
            },
            line: {
                width: Point.line,
                type: Point.$el.data('Point.linetype') || Points.$el.data('Point.linetype') || 'round'
            },
            dash: Point.$el.data('Point.linedash') || Points.$el.data('Point.linedash') || 'dashed'
        };

        Point.point.start.x += Point.point.offset.start.x;
        Point.point.start.y += Point.point.offset.start.y;

        Point.point.end.x += Point.point.offset.end.x;
        Point.point.end.y += Point.point.offset.end.y;

        Point.point.control.x = Point.point.start.x + Point.point.curve.x;
        Point.point.control.y = Point.point.end.y + Point.point.curve.y;

        Point.ctx.beginPath();

        Point.ctx.moveTo(
            Point.point.start.x,
            Point.point.start.y
        );

        if (!Points.mobile) {
            Point.ctx.quadraticCurveTo(
                Point.point.control.x,
                Point.point.control.y,
                Point.point.end.x,
                Point.point.end.y
            );
        }
        else {
            Point.ctx.lineTo(
                Point.point.start.x + Point.$start.parent().width(),
                Point.point.start.y
            );
        }

        Point.ctx.lineWidth = Point.point.line.width;

        // Dashed mode
        Point.ctx.lineCap = Point.point.line.type;
        Point.ctx.miterLimit = Point.point.width;

        if (Point.point.dash === 'dashed' || Point.point.dash === 'dotted') {
            var size = Point.point.dash === 'dotted' ? [0, 20] : [10, 20];

            if (typeof Point.ctx.setLineDash !== 'undefined') {
                Point.ctx.setLineDash(size);
            }
            else if (typeof Point.ctx.mozDash !== 'undefined') {
                Point.ctx.mozDash = size;
            }
        }

        // Gradient
        if (!Points.mobile) {
            Point.grd = Point.ctx.createLinearGradient(0, 0, 0, Point.$canvas.height());
        }
        else {
            Point.grd = Point.ctx.createLinearGradient(0, 0, Point.$canvas.width(), 0);
        }
        Point.grd.addColorStop(0, Point.point.gradient.one);
        Point.grd.addColorStop(0.2, Point.point.gradient.one);
        Point.grd.addColorStop(0.8, Point.point.gradient.two);
        Point.grd.addColorStop(1, Point.point.gradient.two);

        // Point.line color
        Point.ctx.strokeStyle = Point.grd;
        Point.ctx.stroke();
    }

    $.fn.pointConnect = function () {

        return this.each(function () {

            var self = $(this),
                Points = {
                    $el: $(this),
                    $items: $(this).find('.history-content'),
                    point: {}
                },
                Starts = $(this).find('.startpoint'),
                Ends = $(this).find('.endpoint');


            Points.wwidth = $(window).width();
            Points.mobile = Points.wwidth < 768;

            $(this).data('points', Points);

            Points.$items.each(function (key, element) {
                var Point = {
                    $el: $(this),
                    $start: Starts.eq(key),
                    $end: Ends.eq(key + 1),
                    $canvas: $('<canvas class="pointer-canvas" />'),
                    line: $(this).data('linewidth') || Points.$el.data('linewidth') || 10,
                    points: Points
                };

                // Skip if no valid Point.$end found.
                if (!Points.mobile && (Point.$end.length == 0 || Point.$start.length == 0)) {
                    return true;
                }

                Point
                    .$canvas
                    .attr('width', self.innerWidth())
                    .attr('height', ((Point.$end.length ? Point.$end.offset().top : Point.$start.height())  - Point.$start.offset().top) + (Point.line * 10)  + 100)
                    .css({
                        zIndex: 1,
                        position: 'absolute',
                        left: 0,
                        top: Point.$start.position().top - self.position().top
                    })
                    .prependTo(Point.$el);

                Point.$el.data('point', Point);

                if (jQuery.fn.waypoint && $(this).next().hasClass('wpb_animate_when_almost_visible') && !$(this).next().hasClass('animated')) {
                    $(this).next().on('animationend webkitAnimationEnd oAnimationEnd', function() {
                        var self = $(this).prev(),
                            point = self.data('point');

                        point.timer && clearTimeout(point.timer);
                        point.timer = setTimeout(function () {
                            HistoryCreatePoints(self.closest('.history-elements').data('points'), point);
                        }, 50);
                    });
                    /**$(this).next().waypoint(function () {
                        var self = $(this).prev(),
                            point = self.data('point');

                        point.timer && clearTimeout(point.timer);
                        point.timer = setTimeout(function () {
                            HistoryCreatePoints(self.closest('.history-elements').data('points'), point);
                        }, 50);
                    }, {offset: "100%"})**/
                }
                else {
                    HistoryCreatePoints(Points, Point);
                }
            });

        });
    };

    var HistoryConnector = {
        wwidth: $(window).width(),
        timer: false,
        page: $('#page')
    }

    if (HistoryConnector.page.length && HistoryConnector.page.hasClass('animsition')) {
        $(window)
            .on('animsitionPageIn', function () {

                $('.pointer-canvas').remove();
                $('.point-connector').pointConnect();

                $(window)
                    .on('sortupdate.pointer', function () {
                        $('.pointer-canvas').remove();
                        $('.point-connector').pointConnect();
                    })
                    .on('resize.pointer', function () {
                        if (HistoryConnector.wwidth != $(window).width()) {
                            clearTimeout(HistoryConnector.timer);
                            HistoryConnector.timer = setTimeout(function () {
                                $('.pointer-canvas').remove();
                                $('.point-connector').pointConnect();

                                HistoryConnector.wwidth = $(window).width();
                            }, 50);
                        }
                    });

            });
    }
    else {
        $(window)
            .on('load.pointer sortupdate.pointer', function () {
                $('.pointer-canvas').remove();
                $('.point-connector').not('.wpb_animate_when_almost_visible').pointConnect();

            })
            .on('resize.pointer', function () {
                if (HistoryConnector.wwidth != $(window).width()) {
                    clearTimeout(HistoryConnector.timer);
                    HistoryConnector.timer = setTimeout(function () {
                        $('.pointer-canvas').remove();
                        $('.point-connector').pointConnect();

                        HistoryConnector.wwidth = $(window).width();
                    }, 50);
                }
            });
    }


})(jQuery);