<?php

/**
 * Class for building the history inner content.
 *
 * @author jason.xie@victheme.com
 * @method HsInner($context)
 */
class VTCore_History_Element_HsInner
    extends VTCore_Bootstrap_Grid_BsColumn
{

    protected $context = array(
        'type' => 'div',
        'text' => '',
        'attributes' => array(
            'class' => array(
                'history-content',
            ),
        ),

        'left_element' => array(
            'type' => 'div',
            'attributes' => array(
                'class' => array(
                    'history-left',
                ),
            ),
        ),

        'right_element' => array(
            'type' => 'div',
            'attributes' => array(
                'class' => array(
                    'history-right',
                ),
            ),
        ),
        'image_element' => array(
            'size' => 'medium',
            'attributes' => array(
                'class' => array('history-image'),
            ),
        ),
        'icon_element' => array(
            'attributes' => array(
                'class' => array(
                    'history-icon',
                ),
            ),
        ),
        'title_and_endpoint_wrapper' => array(
            'type' => 'div',
            'attributes' => array(
                'class' => array(
                    'history-title-endpoint-wrapper',
                )
            ),
        ),
        'title_element' => array(
            'type' => 'h2',
            'attributes' => array(
                'class' => array(
                    'history-title',
                )
            ),
        ),
        'subtitle_element' => array(
            'type' => 'h3',
            'attributes' => array(
                'class' => array(
                    'history-subtitle',
                )
            ),
        ),

        'startpoint_element' => array(
            'type' => 'div',
            'attributes' => array(
                'class' => array(
                    'startpoint',
                )
            ),
        ),

        'endpoint_element' => array(
            'type' => 'span',
            'attributes' => array(
                'class' => array(
                    'endpoint',
                )
            ),
        ),
        'content' => false,

        'enable' => array(
            'title' => true,
            'subtitle' => true,
            'icon' => true,
            'image' => true,
        ),
    );


    private $left;
    private $right;
    private $startpoint;
    private $icon;
    private $image;
    private $endpointWrapper;

    public function buildElement()
    {

        $this->addAttributes($this->getContext('attributes'));

        $text = $this->getContext('title_element.text');
        $this->removeContext('title_element.text');

        $this->left = $this->BsElement($this->getContext('left_element'))->lastChild();
        $this->right = $this->BsElement($this->getContext('right_element'))->lastChild();
        $this->startpoint = new VTCore_Html_Element($this->getContext('startpoint_element'));
        $this->icon = new VTCore_Fontawesome_faIcon($this->getContext('icon_element'));
        $this->endpointWrapper = $this->right->addChildren(new VTCore_Html_Element($this->getContext('title_and_endpoint_wrapper')))->lastChild();

        $this->endpointWrapper
            ->addChildren(new VTCore_Html_Element($this->getContext('endpoint_element')))
            ->Element($this->getContext('title_element'))
            ->lastChild()
            ->Element(array(
                'type' => 'span',
                'text' => $text,
                'attributes' => array(
                    'class' => array(
                        'title-text',
                    )
                ),
            ));


        if ($this->findContext('attachment_id')) {

            $style = $this->getContext('image_style');
            $this->addClass('history-image-' . $style);

            if (strpos($style, '_circle_2') !== false || $style == 'diamond') {
                $this->addContext('image_element.force.square', true);
                $style = str_replace('_circle_2', '_circle', $style);
            }

            $styleClass = array(
                'wrapper' => 'vc_single_image-wrapper',
                'style' => $style,
            );

            $style_box3d = '';
            if ($style == 'vc_box_shadow_3d') {
                $style_box3d = 'vc_box_shadow_3d_wrap';
            }

            if ($this->getContext('border_color')) {
                $styleClass['border'] = ' vc_box_border_' . $this->getContext('border_color');
            }

            $this->image = $this->left
                ->Element(array(
                    'type' => 'div',
                    'attributes' => array(
                        'class' => array(
                            'wpb_single_image'
                        )
                    )
                ));

            $this->image
                ->lastChild()
                ->Element(array(
                    'type' => 'div',
                    'attributes' => array(
                        'class' => $styleClass,
                    ),
                ))
                ->lastChild()
                ->Element(array(
                    'type' => 'span',
                    'attributes' => array(
                        'class' => array(
                            $style_box3d,
                        ),
                    ),
                ))
                ->lastChild()
                ->addChildren(new VTCore_Wordpress_Element_WpImage($this->getContext('image_element')));
        }

        $this->left->addChildren($this->startpoint);

        $this->startpoint->addChildren($this->icon);

        $this->right
            ->Element($this->getContext('subtitle_element'))
            ->Element(array(
                'type' => 'div',
                'attributes' => array(
                    'class' => array(
                        'history-text',
                    ),
                ),
                'text' => $this->getContext('content'),
                'raw' => true,
            ));


        // Allow user to hijack and alter the history element.
        do_action('vtcore_history_alter_history_content_object', $this);
    }

    public function getLeft()
    {
        return $this->left;
    }

    public function getRight()
    {
        return $this->right;
    }

    public function getIcon()
    {
        return $this->icon;
    }

    public function getImage()
    {
        return $this->image;
    }
}