<?php

/**
 * Main Class for handling the Plugin operation
 *
 * @author jason.xie@victheme.com
 *
 */
class VTCore_History_Init
{

    private $autoloader;

    private $filters = array(
        'vc_load_default_templates',
    );

    private $actions = array(
        'vc_backend_editor_enqueue_js_css',
        'vc_frontend_editor_enqueue_js_css',
        'vc_load_iframe_jscss',
    );

    private $shortcodes = array(
        'history' => 'VTCore_History_Shortcodes_History',
        'historyinner' => 'VTCore_History_Shortcodes_HistoryInner',
        'historysimple' => 'VTCore_History_Shortcodes_HistorySimple',
    );

    private $vcshortcodes = array(
        'VTCore_History_Visualcomposer_History',
        'VTCore_History_Visualcomposer_HistoryInner',
        'VTCore_History_Visualcomposer_HistorySimple',
    );


    /**
     * Constructing the main class and adding action to init.
     */
    public function __construct()
    {

        // Load autoloader
        $this->autoloader = new VTCore_Autoloader('VTCore_History', dirname(__FILE__));
        $this->autoloader->setRemovePath('vtcore' . DIRECTORY_SEPARATOR . 'history' . DIRECTORY_SEPARATOR);
        $this->autoloader->register();

        // Registering assets
        VTCore_Wordpress_Init::getFactory('assets')
            ->get('library')
            ->detect(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'assets', plugins_url('', __FILE__) . '/assets', false, 'VTCore_History_Assets');

        // Registering actions
        VTCore_Wordpress_Init::getFactory('filters')
            ->addPrefix('VTCore_History_Filters_')
            ->addHooks($this->filters)
            ->register();

        // Registering filters
        VTCore_Wordpress_Init::getFactory('actions')
            ->addPrefix('VTCore_History_Actions_')
            ->addHooks($this->actions)
            ->register();


        // Registering shortcodes
        VTCore_Wordpress_Init::getFactory('shortcodes')
            ->merge($this->shortcodes)
            ->initialize();


        // Register to visual composer via VTCore Visual Composer Factory
        if (VTCore_Wordpress_Init::getFactory('visualcomposer')) {
            VTCore_Wordpress_Init::getFactory('visualcomposer')
                ->mapShortcode($this->vcshortcodes);
        }

        // Force convert shortcode into dotted notation, some theme like flatsome
        // invoke function that messed up with underscore (flatsome_contentfix)
        add_filter('the_content', function ($content) {
            $shortcodes = ['historyline', 'historylinesimple'];
            foreach ($shortcodes as $shortcode) {
                if (has_shortcode($content, $shortcode)) {
                    $pattern = get_shortcode_regex(array($shortcode));
                    $atts = [];
                    preg_match_all('/' . $pattern . '/s', $content, $atts);

                    if (!empty($atts[0])) {
                        $content = str_replace($atts[0], str_replace('___', '.', $atts[0]), $content);
                    }
                }

            }
            return $content;
        }, 999);
    }

}