<?php

/**
 * Class extending the Shortcodes base class
 * for building the history element
 *
 * how to use :
 *
 * [history
 *   class="some class"
 *   id="someid"
 *   gradientone="hex to serve as gradient one fallback"
 *   gradienttwo="hex to serve as gradient two fallback"
 *   curvex="curve x fallback"
 *   curvey="curve y fallback"
 *   startx="start x fallback"
 *   starty="start y fallback"
 *   endx="end x fallback"
 *   endy="end y fallback"
 *   linewidth="line width fallback"
 *   linetype=" line type fallback"]
 *
 * [historyinner
 *   id="x"
 *   class="class_one class_two"
 *   direction="left|right|center"
 *   image_attachmentid="wp attachment id or image url"
 *   image_size="the image size using numeric widthxheight or wp image size"
 *   image_position="the position for the image"
 *   border_color="the border color as vc border color"
 *   image_style="extra css class to style the image"
 *   icon_icon="fontawesome icon class"
 *   icon_size="the icon size utilizing fontawesome icon sizing"
 *   icon_rotate="rotate value for the icon"
 *   icon_flip="flip the icon or not"
 *   icon_spin="spin the icon"
 *   icon_border="the border value for the icon wrapper"
 *   icon_shape="the custom shape for the icon"
 *   icon_position="the position for the icon"
 *   icon_inner_padding="the padding for the icon"
 *   icon_font="the fontsize for the icon overriding the fontawesome icon size rule"
 *   icon_width="the width for the icon wrapper"
 *   icon_height="the height for the icon wrapper"
 *   icon_color="the color for the icon"
 *   icon_background="the background color for the wrapper element"
 *   icon_border_color="the border color for the icon"
 *   label_type="the type for the label according to bootstrap label types"
 *   label_fontcolor="the font color for the label element"
 *   label_text="the text for the label"
 *   label_background="the label background color"
 *   title="some title"
 *   title_class="extra css class for title"
 *   subtitle="some subtitle"
 *   subtitle_class="extra css class for subtitle"
 *   data_curve_x="numeric representing pixel value for quadratic curve control point x relative to starting point x"
 *   data_curve_y="numeric representing pixel value for quadratic curve control point y relative to starting point y"
 *   data_offset_start_x="numeric representing pixel value for offsetting the start x"
 *   data_offset_start_y="numeric representing pixel value for offsetting the start y"
 *   data_offset_end_x="numeric representing pixel value for offsetting the end x"
 *   data_offset_end_y="numeric representing pixel value for offsetting the end y"
 *   data_gradientone="hex value for gradient value one"
 *   data_gradienttwo="hex value for gradient value two"
 *   data_linewidth="numeric representing the width of the conneting line"
 *   data_linetype="butt|round|square"
 *   data_linedash="line|dashed|dotted"
 * ]
 *
 *   some content for the inner shortcodes allowed
 *
 * [/historyinner]
 *
 * [/history]
 *
 *
 * @author jason.xie@victheme.com
 *
 */
class VTCore_History_Shortcodes_History
    extends VTCore_Wordpress_Models_VCShortcodes
    implements VTCore_Wordpress_Interfaces_Shortcodes
{

    protected $processDottedNotation = true;

    protected $data = array(
        'gradientone' => false,
        'gradienttwo' => false,
        'curvex' => false,
        'curvey' => false,
        'startx' => false,
        'starty' => false,
        'endx' => false,
        'endy' => false,
        'linewidth' => false,
        'linetype' => false,
        'linedash' => false,
    );

    protected $defaults = array(
        'direction' => 'alternate',
        'curvex' => 0,
        'curvey' => 100,
        'startx' => 0,
        'starty' => 0,
        'endx' => 0,
        'endy' => 0,
        'linewidth' => 10,
        'linetype' => 'round',
        'linedash' => 'dotted',
        'gradientone' => '',
        'gradienttwo' => ''
    );

    public function buildObject()
    {
        $this->atts = VTCore_Wordpress_Utility::arrayMergeRecursiveDistinct($this->atts, $this->defaults);
        $this->object = new VTCore_History_Element_HsElement($this->atts);
        $this->object->addChildren(do_shortcode($this->content));
    }
}