<?php

/**
 * Class extending the Shortcodes base class
 * for building simple history line. This is created
 * for a very simple history line object.
 *
 * how to use :
 *
 * [historysimple
 *   class="some class"
 *   id="someid"
 *   contentargs="url decoded arrays of content"
 *   gradientone="hex to serve as gradient one fallback"
 *   gradienttwo="hex to serve as gradient two fallback"
 *   linewidth="line width fallback"
 *   linetype=" line type fallback"
 * ]
 *
 *
 * @author jason.xie@victheme.com
 *
 */
class VTCore_History_Shortcodes_HistorySimple
    extends VTCore_Wordpress_Models_VCShortcodes
    implements VTCore_Wordpress_Interfaces_Shortcodes
{

    protected $processDottedNotation = true;

    /**
     * Extending parent method.
     * @see VTCore_Wordpress_Models_Shortcodes::processCustomRules()
     */
    protected function processCustomRules()
    {

        if ($this->get('contentargs')) {
            $this->add('contents', json_decode(urldecode($this->get('contentargs')), true));
        }

        $this
            ->add('attributes.class.shortcode', 'historyline-simple');

        // Processing content
        foreach ($this->get('contents') as $delta => $content) {
            $object = new VTCore_Wordpress_Objects_Array($content);
            $object
                ->add('data_gradientone', $this->get('gradientone'))
                ->add('data_gradienttwo', $this->get('gradienttwo'))
                ->add('data_linewidth', $this->get('linewidth'))
                ->add('data_linetype', $this->get('linetype'))
                ->add('data_linedash', $this->get('linedash'))
                ->add('icon_icon', $this->get('icon_icon'))
                ->add('icon_color', $this->get('icon_color'))
                ->add('icon_background', $this->get('icon_background'))
                ->add('image_style', $this->get('image.style'))
                ->add('css_animation', $this->get('css_animation'));


            // Build Image
            if ($object->get('image_attachmentid')) {
                $object
                    ->add('image_style', $this->get('image.style'))
                    ->add('image_size', 'full');
            }

            $this->add('contents.' . $delta, $object->extract());
            unset($object);
            $object = null;

        }

        $this->remove('css_animation');
    }


    public function buildObject()
    {

        $this->object = new VTCore_History_Element_HsElement($this->atts);

        if ($this->get('contents')) {
            $markup = '';
            foreach ($this->get('contents') as $delta => $content) {
                $data = new VTCore_Wordpress_Objects_Array($content);
                $shortcode = new VTCore_History_Shortcodes_HistoryInner($data->extract(), $data->get('content'), 'historyinner');
                $shortcode->buildObject();
                $markup .= $shortcode->getMarkup();

                unset($data);
                $data = NULL;

                unset($shortcode);
                $shortcode = NULL;
            }

            if (!empty($markup)) {
                $this->object->addChildren($markup);
            }
        }
    }
}


