/**
 *
 * Integrating to VisualComposer
 *
 * @author jason.xie@victheme.com
 */
(function ($) {

     var VTTimeLine = {
        build: function (model) {

            if (typeof model == 'undefined') {
                return;
            }
            _.defer(function () {
                model.vertical = model.view.$el.find('[data-layout="vertical"]');
                model.horizontal = model.view.$el.find('[data-layout="horizontal"]');
                if (model.vertical.length) {
                    model.vertical.VTCoreVerticalTimeline();
                }
                if (model.horizontal.length) {
                    model.horizontal.VTCoreHorizontalTimeline();
                }

            }, this);
        },
        filterAlignmentAgainstLayout: function(element) {
            var value = $(element).val(),
                target = $(element).closest('.vc_edit_form_elements').find('[data-vc-shortcode-param-name="align"]');

            if (!target) {
                target = $(element).closest('.vc_edit_form_elements').find('[data-vc-shortcode-param-name="contentargs_direction"]');
            }

            if (target.length) {

                target.find('option').show();
                if (value == 'vertical') {
                    target.find('option.top, option.bottom').hide();
                }
                else {
                    target.find('option.left, option.right').hide();
                }

                target.val('center');
            }
        },
        filterFormAgainstEventType: function(element) {
            var value = $(element).val(),
                target = $(element).closest('.vc_param').find(
                    '[data-vc-shortcode-param-name="contentargs_direction"], ' +
                    '[data-vc-shortcode-param-name="contentargs_icon"], ' +
                    '[data-vc-shortcode-param-name="contentargs_day"], ' +
                    '[data-vc-shortcode-param-name="contentargs_month"], ' +
                    '[data-vc-shortcode-param-name="contentargs_date"], ' +
                    '[data-vc-shortcode-param-name="contentargs_year"], ' +
                    '[data-vc-shortcode-param-name="contentargs_image"], ' +
                    '[data-vc-shortcode-param-name="contentargs_style"], ' +
                    '[data-vc-shortcode-param-name="contentargs_size"], ' +
                    '[data-vc-shortcode-param-name="contentargs_text"]');

            target.hide();
            if (value == 'events') {
                target.show();
            }
        }
    };

    $(window)
        .on('vc_ready', function () {

            vc.events
                .on('shortcodeView:ready:timeline', function (model) {
                    VTTimeLine.build(model);
                })
                .on('shortcodeView:ready:timelinequery', function (model) {
                    VTTimeLine.build(model);
                })
                .on('shortcodeView:ready:timelinesimple', function (model) {
                    VTTimeLine.build(model);
                })
                .on('shortcodeView:ready:timemajor', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                })
                .on('shortcodes:timemajor:destroy', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                })
                .on('shortcodeView:ready:timestart', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                })
                .on('shortcodes:timestart:destroy', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                })
                .on('shortcodeView:ready:timeend', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                })
                .on('shortcodes:timeend:destroy', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                })
                .on('shortcodeView:ready:timeevents', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                })
                .on('shortcodes:timeevents:destroy', function (model) {
                    VTTimeLine.build(vc.shortcodes.get(model.get('parent_id')));
                });


        });

    // Make sure we are on the right window
    if ($(document).find('#vc_ui-panel-edit-element').length) {

        VTTimeLine.filterAlignmentAgainstLayout($('.js-timeline-layout select')[0]);
        VTTimeLine.filterFormAgainstEventType($('[name="contentargs_timetype"]')[0]);

        $(document)
            .on('click.timeline-direction', '.column_toggle', function() {
                VTTimeLine.filterFormAgainstEventType($('[name="contentargs_timetype"]')[0]);
            })
            .on('ready.timeline-direction', function() {
                VTTimeLine.filterAlignmentAgainstLayout($('.js-timeline-layout select')[0]);
                VTTimeLine.filterFormAgainstEventType($('[name="contentargs_timetype"]')[0]);
            })

            .on('change.timeline_events blur.timeline_events', '[name="contentargs_timetype"]', function() {
                VTTimeLine.filterFormAgainstEventType(this);
            })

            // Don't allow horizontal to have left and right and vertical to have top and bottom
            .on('change.timeline_direction blur.timeline_direction', '.js-timeline-layout select', function () {
                VTTimeLine.filterAlignmentAgainstLayout(this);
            })

            // Initial loading trigger the change events
            .on('ajaxComplete', function () {
                $('.js-timeline-layout select')
                    .each(function () {
                        VTTimeLine.filterAlignmentAgainstLayout(this);
                    });
            });
    }


})(window.jQuery);
