(function ($) {

    var VTTimeLine = function ($el, init) {
        this.$parent = $el;
        this.$el = this.$parent.find('[data-timeline="element"]');
        this.$children = this.$parent.find('[data-timeline="items"]');
        this.$bar = this.$parent.find('[data-timeline="bar"]');
        this.destroy();
        init && this.init();
        return this;
    };

    VTTimeLine.prototype = {
        init: function () {
            this
                .calculate()
                .adjustParent()
                .buildScrollbar();

            return this;

        },
        adjustParent: function () {
            this.$parent.css({
                height: this.totalHeight + 'px'
            });
            return this;
        },
        getHeight: function(element, topHeight) {
            var cs = getComputedStyle(element);
            var height = $(element).outerHeight(true);

            height += parseFloat(cs.paddingTop.replace('px', '')) + parseFloat(cs.paddingBottom.replace('px', ''));
            height += parseFloat(cs.borderTopWidth.replace('px', '')) + parseFloat(cs.borderBottomWidth.replace('px', ''));
            height += parseFloat(cs.marginTop.replace('px', '')) + parseFloat(cs.marginBottom.replace('px', ''));

            if (height > topHeight) {
                topHeight = height;
            }

            return topHeight;
        },
        calculate: function () {
            this.totalHeight = 0;
            var that = this;
            if (this.$parent.data('align') === 'center') {
                var topHeight = 0,
                    bottomHeight = 0,
                    top = 0;

                this.$parent.find('[data-direction="top"], [data-direction="left"]').children().each(function () {
                    bottomHeight = that.getHeight(this, bottomHeight);
                });

                this.$parent.find('[data-direction="bottom"], [data-direction="right"]').children().each(function () {
                    topHeight = that.getHeight(this, topHeight);
                });

                this.totalHeight = topHeight + bottomHeight;

                this.$bar.css('top', topHeight);

                this.$parent.find('[data-type="end"], [data-type="major"], [data-type="start"]').children().each(function () {
                    // These elements must have data-direction center!
                    $(this).parent().css('justify-content', 'flex-start').attr('data-direction', 'center');
                    $(this).css('margin-top', (topHeight - $(this).height() / 2 ));
                });

                this.$parent.find('[data-direction="top"], [data-direction="left"]').children().each(function () {
                    $(this).css('top', topHeight);
                });

                this.$parent.find('[data-direction="bottom"], [data-direction="right"]').children().each(function () {
                    $(this).css('bottom', bottomHeight);
                });

                this.$el.css('height', this.totalHeight);
            }
            else {
                this.totalHeight =  this.$children.outerHeight(true);
            }

            return this;
        },
        buildScrollbar: function () {
            this.$parent.customScrollbar({
                skin: 'timeline-skin',
                vScroll: false,
                updateOnWindowResize: true,
                fixedThumbHeight: 24,
                fixedThumbWidth: 48
            });

            this.$parent.find('.viewport').height(this.totalHeight);

            return this;
        },
        destroy: function () {
            this.$parent.removeAttr('style');
            this.$el.removeAttr('style');
            this.$el.children().removeAttr('style');
            this.$parent.parent().find('[style]').removeAttr('style');
            this.$parent.customScrollbar('remove', true);

            return this;
        },
        refresh: function () {
            this.destroy();
            this.init();
        }
    };


    /**
     * Build the horizontal time line element
     */
    $.fn.VTCoreHorizontalTimeline = function () {
        return this.each(function () {
            $(this).removeData('timeline').data('timeline', new VTTimeLine($(this), true));
        });
    };

    /**
     * Build the horizontal time line element
     */
    $.fn.VTCoreVerticalTimeline = function () {
        return this.each(function () {
            $(this).removeData('timeline').data('timeline', new VTTimeLine($(this), false));
        });
    };


    var VTTimeLineHelper = {
        wwidth: $(window).width(),
        timer: 0,
        page: $('#page')
    };


    // VC needs load event for this to work properly!.
    if (VTTimeLineHelper.page.length && VTTimeLineHelper.page.hasClass('animsition')) {
        $(window)
            .on('animsitionPageIn.timeline', function () {

                $('[data-timeline="wrapper"]').filter('[data-layout="horizontal"]').VTCoreHorizontalTimeline();

                $(window)
                    .on('load.timeline sortupdate.timeline', function () {
                        $('[data-timeline="wrapper"]').filter('[data-layout="horizontal"]').VTCoreHorizontalTimeline();
                    })
                    .on('resize.timeline', function () {
                        if (VTTimeLineHelper.wwidth != $(window).width()) {
                            clearTimeout(VTTimeLineHelper.timer);
                            VTTimeLineHelper.timer = setTimeout(function () {
                                $('[data-timeline="wrapper"]').filter('[data-layout="horizontal"]').VTCoreHorizontalTimeline();
                                VTTimeLineHelper.wwidth = $(window).width();
                            }, 50);
                        }
                    });
            });
    }
    else {
        $(window)
            .on('load.timeline sortupdate.timeline', function () {
                $('[data-timeline="wrapper"]')
                    .filter('[data-layout="horizontal"]')
                    .VTCoreHorizontalTimeline();
            })
            .on('resize.timeline', function () {
                if (VTTimeLineHelper.wwidth != $(window).width()) {
                    clearTimeout(VTTimeLineHelper.timer);
                    VTTimeLineHelper.timer = setTimeout(function () {
                        $('[data-timeline="wrapper"]')
                            .filter('[data-layout="horizontal"]')
                            .VTCoreHorizontalTimeline();
                        VTTimeLineHelper.wwidth = $(window).width();
                    }, 50);
                }
            });
    }


})(window.jQuery);